@@ -149,7 +149,7 @@
 #'
 #' <https://nashjc.wordpress.com/2016/11/10/why-optim-is-out-of-date/>
 #'
-#' <https://www.damtp.cam.ac.uk/user/na/NA_papers/NA2009_06.pdf>
+#' Powell, M.J. (2009). The BOBYQA algorithm for bound constrained optimization without derivatives. Report DAMTP 2009/NA06
 #'
 #'
 #'
@@ -374,7 +374,7 @@ fitRTConf <- function(data, model = "dynWEV",
     logger::log_threshold(logger::DEBUG, index=2)
     logger::log_threshold(logger::DEBUG)
     logger::log_layout(logger, index=2)
-    logger::log_errors()
+    #logger::log_errors() # does not work with parallellization
   }
 
 
