@@ -210,7 +210,7 @@ LogLikRM <- function(data, paramDf, model="IRM", time_scaled =FALSE,
   # if (any(probs<=0)) {
   #   return(-1e12)
   # }
-  probs[probs==0] <- .Machine$double.xmin
+  probs[probs==0 | is.na(probs)] <- .Machine$double.xmin
 
   if ("n" %in% names(data)) {
     logl <- sum(log(probs)*data$n)
